@@ -109,10 +109,7 @@ class JobStatusFormatter:
         if job_status.description:
             table.add_row("Description", job_status.description)
         status_text = fmt_status(job_status.status)
-        if job_status.history.reason and job_status.status in [
-            JobStatus.FAILED,
-            JobStatus.PENDING,
-        ]:
+        if job_status.history.reason:
             status_text = Text.assemble(status_text, f" ({job_status.history.reason})")
         table.add_row("Status", status_text)
         table.add_row("Image", self._format_image(job_status.container.image))
@@ -229,7 +226,8 @@ class JobStatusFormatter:
 
         assert job_status.history.created_at is not None
         table.add_row(
-            "Created", self._datetime_formatter(job_status.history.created_at)
+            "Created",
+            self._datetime_formatter(job_status.history.created_at, precise=True),
         )
         if job_status.status in [
             JobStatus.RUNNING,
@@ -240,7 +238,8 @@ class JobStatusFormatter:
         ]:
             assert job_status.history.started_at is not None
             table.add_row(
-                "Started", self._datetime_formatter(job_status.history.started_at)
+                "Started",
+                self._datetime_formatter(job_status.history.started_at, precise=True),
             )
         lifespan_ends = get_lifespan_ends(job_status)
         if lifespan_ends:
@@ -254,7 +253,8 @@ class JobStatusFormatter:
         ]:
             assert job_status.history.finished_at is not None
             table.add_row(
-                "Finished", self._datetime_formatter(job_status.history.finished_at)
+                "Finished",
+                self._datetime_formatter(job_status.history.finished_at, precise=True),
             )
             table.add_row("Exit code", str(job_status.history.exit_code))
         if job_status.status == JobStatus.FAILED and job_status.history.description:
@@ -268,7 +268,8 @@ class JobStatusFormatter:
                 if status_item.reason:
                     status_text = Text.assemble(status_text, f" ({status_item.reason})")
                 status_transitions.add_row(
-                    status_text, self._datetime_formatter(status_item.transition_time)
+                    status_text,
+                    self._datetime_formatter(status_item.transition_time, precise=True),
                 )
             table.add_row(
                 "Status transitions", Styled(status_transitions, style="reset")
@@ -367,7 +368,7 @@ class JobTelemetryFormatter(RenderHook):
         if self._console.is_terminal:
             self._live_render.set_renderable(table)
             with self._console:
-                self._console.print(Control(""))
+                self._console.print(Control())
         else:
             self._console.print(table)
         self.changed = False
@@ -605,11 +606,17 @@ class DetailedJobStartProgress(JobStartProgress, RenderHook):
 
         self._live_render.set_renderable(msg)
         with self._console:
-            self._console.print(Control(""))
+            self._console.print(Control())
 
     def end(self, job: JobDescription) -> None:
         out = []
 
+        if self._prev:
+            self._console.print(self._prev)
+            empty = Text("")
+            self._prev = empty
+            self._live_render.set_renderable(empty)
+
         if job.status != JobStatus.FAILED:
             http_url = job.http_url
             if http_url:
@@ -645,9 +652,9 @@ class DetailedJobStartProgress(JobStartProgress, RenderHook):
         exc_val: BaseException,
         exc_tb: TracebackType,
     ) -> None:
+        self._console.pop_render_hook()
         self._console.line()
         self._console.show_cursor(True)
-        self._console.pop_render_hook()
 
 
 class StreamJobStartProgress(JobStartProgress):
@@ -779,7 +786,7 @@ class DetailedJobStopProgress(JobStopProgress, RenderHook):
 
         self._live_render.set_renderable(Text.from_markup(msg))
         with self._console:
-            self._console.print(Control(""))
+            self._console.print(Control())
 
     def timeout(self, job: JobDescription) -> None:
         self._console.line()
@@ -819,9 +826,9 @@ class DetailedJobStopProgress(JobStopProgress, RenderHook):
         exc_val: BaseException,
         exc_tb: TracebackType,
     ) -> None:
+        self._console.pop_render_hook()
         self._console.line()
         self._console.show_cursor(True)
-        self._console.pop_render_hook()
 
 
 class StreamJobStopProgress(JobStopProgress):
@@ -912,7 +919,7 @@ class DetailedExecStopProgress(ExecStopProgress, RenderHook):
 
         self._live_render.set_renderable(Text.from_markup(msg))
         with self._console:
-            self._console.print(Control(""))
+            self._console.print(Control())
 
     def timeout(self) -> None:
         self._console.line()
